import type { SpinnerProps } from '@blueprintjs/core'
import { Spinner } from '@blueprintjs/core'
import { useApolloNetworkStatus } from '@inject/graphql/client'
import { useGetExerciseTimeLeft } from '@inject/graphql/queries/GetExerciseTimeLeft.generated'
import { HEALTH_CHECK_INTERVAL } from '../utilities'

const HealthCheck = () => {
  const { loading, error } = useGetExerciseTimeLeft({
    pollInterval: HEALTH_CHECK_INTERVAL,
  })
  const { numPendingQueries, numPendingMutations } = useApolloNetworkStatus()

  let spinnerProps: SpinnerProps
  if (loading) {
    spinnerProps = {
      value: undefined,
      intent: 'danger',
      title: 'loading',
    }
  } else if (error) {
    spinnerProps = {
      value: 1,
      intent: 'danger',
      title: 'error',
    }
  } else if (numPendingQueries > 0) {
    spinnerProps = {
      value: undefined,
      intent: 'warning',
      title: 'querying',
    }
  } else if (numPendingMutations > 0) {
    spinnerProps = {
      value: undefined,
      intent: 'warning',
      title: 'updating',
    }
  } else {
    spinnerProps = {
      value: 1,
      intent: 'success',
      title: 'running',
    }
  }

  return (
    <Spinner
      size={20}
      value={spinnerProps.value}
      intent={spinnerProps.intent}
      title={`backend status: ${spinnerProps.title}`}
    />
  )
}

export default HealthCheck
