import { makeVar, useReactiveVar } from '@inject/graphql/client/reactive'

export interface Team {
  exerciseId: string
  teamRole: string
  teamId: string
  show: boolean
  inactive: boolean
}

interface TeamState {
  [key: string]: Team
}

const key = 'team'
const initialSettings: TeamState = JSON.parse(localStorage.getItem(key) || '{}')

export const teams = makeVar<TeamState>(initialSettings)
export const useTeams = () => useReactiveVar(teams) as TeamState

function change(value: TeamState) {
  localStorage.setItem(key, JSON.stringify(value))
}

export const toggleTeam = (team: string) => {
  const prev = teams() as TeamState
  const chosenTeam = prev[team]
  teams({
    ...prev,
    [team]: {
      ...chosenTeam,
      show: !chosenTeam.show,
    },
  })
}

export const unsetTeams = () => {
  const prev = teams() as TeamState
  teams(
    Object.fromEntries(
      Object.entries(prev).map(([key, value]) => [
        key,
        { ...value, show: false },
      ])
    )
  )
}

teams.onNextChange(function onNext() {
  change(teams())
  teams.onNextChange(onNext)
})
