import { toggleTeam, useTeams } from '@/clientsettings/vars/teams'
import LinkButton from '@/components/LinkButton'
import { useParams } from '@/router'
import {
  Button,
  Checkbox,
  Dialog,
  DialogBody,
  DialogFooter,
  Divider,
} from '@blueprintjs/core'
import { useSubscriptionContext } from '@inject/graphql/context/SubscriptionContext'
import type { FC } from 'react'
import { useEffect, useState } from 'react'
import LabelElement from './LabelElement'
import Reloader from './Reloader'
import useTeamStateValidator from './useTeamStateValidator'

interface InstructorTeamSelectorProps {
  hideLabel?: boolean
}

const InstructorTeamSelector: FC<InstructorTeamSelectorProps> = ({
  hideLabel,
}) => {
  const validator = useTeamStateValidator()
  const state = useTeams()
  const cleaned = state ?? {}
  // todo: this should've been already gone, remove
  const { teamId } = useParams('/instructor/:exerciseId/:teamId')
  const { subscribeTeam } = useSubscriptionContext()

  const [openSelector, setOpenSelector] = useState(false)

  const teams = Object.values(cleaned) || []
  const selectedTeams = teams.filter(x => x.show)

  useEffect(() => {
    validator()
  }, [])

  // todo: add handler to accessing teams outside of said range
  useEffect(
    () => subscribeTeam(selectedTeams.map(x => x.teamId)),
    [subscribeTeam, selectedTeams]
  )

  useEffect(() => {
    if (selectedTeams.length === 0) {
      setOpenSelector(true)
    }
  }, [selectedTeams, setOpenSelector])

  return (
    <>
      <Button
        active={openSelector}
        icon='select'
        alignText='left'
        fill
        minimal
        text={!hideLabel && 'Select teams'}
        title='Select teams'
        onClick={() => setOpenSelector(!openSelector)}
      />
      {selectedTeams.map(team => (
        <LinkButton
          key={team.teamId}
          link={[
            '/instructor/:exerciseId/:teamId',
            {
              params: {
                exerciseId: team.exerciseId,
                teamId: team.teamId,
              },
            },
          ]}
          button={{
            active: team.teamId === teamId,
            alignText: 'left',
            fill: true,
            minimal: true,
            title: team.teamRole || `Team ${team.teamId}`,
            children: <LabelElement team={team} hideLabel={hideLabel} />,
          }}
        />
      ))}

      <Dialog
        style={{ width: 'unset' }}
        isOpen={openSelector}
        onClose={() => setOpenSelector(false)}
        canOutsideClickClose={false}
        icon='team'
        title='Team Selection'
      >
        <DialogBody>
          {teams.map((team, i) => (
            <div key={team.teamId}>
              <Checkbox
                key={team.teamId}
                onChange={() => {
                  toggleTeam(team.teamId)
                }}
                checked={team.show}
                alignIndicator='right'
                inline={false}
                labelElement={<LabelElement team={team} />}
                disabled={false}
              />
              {i < teams.length - 1 && <Divider />}
            </div>
          ))}
        </DialogBody>
        <DialogFooter
          actions={
            <Button
              onClick={() => setOpenSelector(false)}
              icon='tick'
              text='Confirm Selection'
            />
          }
        >
          <Reloader />
        </DialogFooter>
      </Dialog>
    </>
  )
}

export default InstructorTeamSelector
