import { teams, useTeams } from '@/clientsettings/vars/teams'
import { useGetRunningExercises } from '@inject/graphql/queries/GetRunningExercises.generated'
import notEmpty from '@inject/shared/utils/notEmpty'

const useTeamStateValidator = () => {
  const teamsVar = useTeams()

  const { refetch } = useGetRunningExercises({
    fetchPolicy: 'network-only',
  })

  return async () => {
    const { data } = await refetch()
    if (!data || !data.exercises) return
    const runningExercises = data.exercises.filter(notEmpty)
    if (runningExercises.length === 0 || !data.exercises[0]) {
      teams(
        Object.fromEntries(
          Object.entries(teamsVar).map(([key, value]) => [
            key,
            { ...value, inactive: true },
          ])
        )
      )
      return
    }
    const newState = data.exercises
      .flatMap(x =>
        x?.teams.map(team => [
          team.id,
          {
            exerciseId: x.id,
            teamRole: team.role,
            teamId: team.id,
            show: false,
            inactive: false,
          },
        ])
      )
      .filter(notEmpty)

    teams({
      ...Object.fromEntries(newState),
      ...(teamsVar
        ? Object.fromEntries(
            Object.entries(teamsVar)
              .filter(([, value]) =>
                runningExercises.some(x => value.exerciseId === x.id)
              )
              .map(([key, value]) => [
                key,
                {
                  ...value,
                  inactive: !runningExercises.some(
                    x => value.exerciseId === x.id
                  ),
                },
              ])
          )
        : {}),
    })
  }
}

export default useTeamStateValidator
