import { useAuthIdentity } from '@inject/graphql/auth'
import { useNotifyContext } from '@inject/shared/notification/contexts/NotifyContext'
import { useEffect } from 'react'
import { useNavigate } from 'react-router-dom'

export const useSetPageTitle = (title: string) => {
  useEffect(() => {
    document.title = `INJECT - ${title}`
  }, [title])
}

export const NOTIFICATION_SELECTION_ID = '-2'
export const CUSTOM_INJECT_SELECTION_ID = '-1'

export const useStaffBoundary = () => {
  const { isStaff } = useAuthIdentity()
  const nav = useNavigate()
  const { notify } = useNotifyContext()

  useEffect(() => {
    if (!isStaff) {
      notify('You are not authorized to access this page', { intent: 'danger' })
      nav('/')
    }
  })
}

export const useSuperuserBoundary = () => {
  const { isSuperuser } = useAuthIdentity()
  const nav = useNavigate()
  const { notify } = useNotifyContext()

  useEffect(() => {
    if (!isSuperuser) {
      notify('You are not authorized to access this page', { intent: 'danger' })
      nav('/')
    }
  })
}

export const useActiveBoundary = () => {
  const { isActive } = useAuthIdentity()
  const nav = useNavigate()
  const { notify } = useNotifyContext()

  useEffect(() => {
    if (!isActive) {
      notify('Your account is not active', { intent: 'danger' })
      nav('/')
    }
  })
}
